gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r23789 - gnunet/src/gns


From: gnunet
Subject: [GNUnet-SVN] r23789 - gnunet/src/gns
Date: Fri, 14 Sep 2012 13:24:58 +0200

Author: schanzen
Date: 2012-09-14 13:24:58 +0200 (Fri, 14 Sep 2012)
New Revision: 23789

Modified:
   gnunet/src/gns/gns.h
   gnunet/src/gns/gnunet-gns-proxy-setup-ca
   gnunet/src/gns/gnunet-gns-proxy.c
   gnunet/src/gns/gnunet-service-gns_interceptor.c
   gnunet/src/gns/gnunet-service-gns_resolver.c
   gnunet/src/gns/test_gns_cname_lookup.c
   gnunet/src/gns/test_gns_dht_delegated_lookup.c
   gnunet/src/gns/test_gns_dht_three_peers.c
   gnunet/src/gns/test_gns_max_queries.c
   gnunet/src/gns/test_gns_ns_lookup.c
   gnunet/src/gns/test_gns_proxy.c
   gnunet/src/gns/test_gns_pseu_shorten.c
   gnunet/src/gns/test_gns_revocation.c
   gnunet/src/gns/test_gns_simple_delegated_lookup.c
   gnunet/src/gns/test_gns_simple_get_authority.c
   gnunet/src/gns/test_gns_simple_lookup.c
   gnunet/src/gns/test_gns_simple_mx_lookup.c
   gnunet/src/gns/test_gns_simple_shorten.c
   gnunet/src/gns/test_gns_simple_srv_lookup.c
Log:
-towards .gads

Modified: gnunet/src/gns/gns.h
===================================================================
--- gnunet/src/gns/gns.h        2012-09-14 10:43:08 UTC (rev 23788)
+++ gnunet/src/gns/gns.h        2012-09-14 11:24:58 UTC (rev 23789)
@@ -28,7 +28,7 @@
 #ifndef GNS_H
 #define GNS_H
 
-#define GNUNET_GNS_TLD "gnunet"
+#define GNUNET_GNS_TLD "gads"
 #define GNUNET_GNS_TLD_ZKEY "zkey"
 #define GNUNET_GNS_TLD_PLUS "+"
 #define GNUNET_GNS_DHT_MAX_UPDATE_INTERVAL 3600

Modified: gnunet/src/gns/gnunet-gns-proxy-setup-ca
===================================================================
--- gnunet/src/gns/gnunet-gns-proxy-setup-ca    2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/gnunet-gns-proxy-setup-ca    2012-09-14 11:24:58 UTC (rev 
23789)
@@ -1,6 +1,7 @@
 echo "Generating CA"
 
-openssl req -new -x509 -days 3650 -extensions v3_ca -keyout gnscakey.pem -out 
gnscacert.pem -subj "/C=DE/ST=Bavaria/L=Munich/O=GNUnet Naming 
System/OU=GNUnet/CN=GNS Proxy CA/address@hidden" -passout pass:"GNUnet Naming 
System"
+openssl req -new -x509 -days 3650 -extensions v3_ca -keyout gnscakey.pem -out
+gnscacert.pem -subj "/C=DE/ST=Bavaria/L=Munich/O=GADS/OU=GNUnet/CN=GADS Proxy 
CA/address@hidden" -passout pass:"GNUnet Naming System"
 
 echo "Removing passphrase from key"
 openssl rsa -passin pass:"GNUnet Naming System" -in gnscakey.pem -out 
gnscakeynoenc.pem
@@ -21,8 +22,8 @@
 
 if [ -d ~/.pki/nssdb ]; then
   echo "Importing CA into chrome"
-  certutil -D -n "GNS Proxy CA" -d ~/.pki/nssdb >/dev/null 2&>1
-  certutil -A -n "GNS Proxy CA" -t CT,, -d ~/.pki/nssdb < gnscacert.pem
+  certutil -D -n "GADS Proxy CA" -d ~/.pki/nssdb >/dev/null 2&>1
+  certutil -A -n "GADS Proxy CA" -t CT,, -d ~/.pki/nssdb < gnscacert.pem
 fi
 
 

Modified: gnunet/src/gns/gnunet-gns-proxy.c
===================================================================
--- gnunet/src/gns/test_gns_ns_lookup.c 2012-09-14 10:43:08 UTC (rev 23788)
+++ gnunet/src/gns/test_gns_ns_lookup.c 2012-09-14 11:24:58 UTC (rev 23789)
@@ -39,9 +39,9 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.homepage.gnunet"
-#define TEST_DOMAIN_ALT "homepage.gnunet"
-#define TEST_DOMAIN_ALT2 "uk.homepage.gnunet"
+#define TEST_DOMAIN "www.homepage.gads"
+#define TEST_DOMAIN_ALT "homepage.gads"
+#define TEST_DOMAIN_ALT2 "uk.homepage.gads"
 #define TEST_IP_ALT2 "81.187.252.184"
 #define TEST_IP "131.159.74.67"
 #define TEST_IP_NS "216.69.185.1" //ns01.domaincontrol.com

Modified: gnunet/src/gns/test_gns_proxy.c
===================================================================
--- gnunet/src/gns/test_gns_proxy.c     2012-09-14 10:43:08 UTC (rev 23788)
+++ gnunet/src/gns/test_gns_proxy.c     2012-09-14 11:24:58 UTC (rev 23789)
@@ -32,7 +32,7 @@
 #include "gnunet_os_lib.h"
 
 #define PORT 8080
-#define TEST_DOMAIN "www.gnunet"
+#define TEST_DOMAIN "www.gads"
 
 #define TIMEOUT GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_SECONDS, 300)
 

Modified: gnunet/src/gns/test_gns_pseu_shorten.c
===================================================================
--- gnunet/src/gns/test_gns_pseu_shorten.c      2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_pseu_shorten.c      2012-09-14 11:24:58 UTC (rev 
23789)
@@ -43,7 +43,7 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.alicewonderland.bobbuilder.gnunet"
+#define TEST_DOMAIN "www.alicewonderland.bobbuilder.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 
@@ -52,7 +52,7 @@
 #define TEST_AUTHORITY_BOB "bobbuilder"
 #define TEST_AUTHORITY_ALICE "alicewonderland"
 #define TEST_PSEU_ALICE "carol"
-#define TEST_EXPECTED_RESULT "www.carol.short.private.gnunet"
+#define TEST_EXPECTED_RESULT "www.carol.short.private.gads"
 
 #define DHT_OPERATION_TIMEOUT GNUNET_TIME_relative_multiply 
(GNUNET_TIME_UNIT_SECONDS, 30)
 

Modified: gnunet/src/gns/test_gns_revocation.c
===================================================================
--- gnunet/src/gns/test_gns_revocation.c        2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_revocation.c        2012-09-14 11:24:58 UTC (rev 
23789)
@@ -42,7 +42,7 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.bob.gnunet"
+#define TEST_DOMAIN "www.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 

Modified: gnunet/src/gns/test_gns_simple_delegated_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_simple_delegated_lookup.c   2012-09-14 10:43:08 UTC 
(rev 23788)
+++ gnunet/src/gns/test_gns_simple_delegated_lookup.c   2012-09-14 11:24:58 UTC 
(rev 23789)
@@ -56,7 +56,7 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.bob.gnunet"
+#define TEST_DOMAIN "www.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 

Modified: gnunet/src/gns/test_gns_simple_get_authority.c
===================================================================
--- gnunet/src/gns/test_gns_simple_get_authority.c      2012-09-14 10:43:08 UTC 
(rev 23788)
+++ gnunet/src/gns/test_gns_simple_get_authority.c      2012-09-14 11:24:58 UTC 
(rev 23789)
@@ -42,14 +42,14 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.alice.bob.gnunet"
+#define TEST_DOMAIN "www.alice.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 
 #define TEST_AUTHORITY_BOB "bob"
 #define TEST_AUTHORITY_ALICE "alice"
 #define TEST_ALICE_PSEU "carol"
-#define TEST_EXPECTED_RESULT "alice.bob.gnunet"
+#define TEST_EXPECTED_RESULT "alice.bob.gads"
 
 #define KEYFILE_BOB 
"../namestore/zonefiles/HGU0A0VCU334DN7F2I9UIUMVQMM7JMSD142LIMNUGTTV9R0CF4EG.zkey"
 #define KEYFILE_ALICE 
"../namestore/zonefiles/N0UJMP015AFUNR2BTNM3FKPBLG38913BL8IDMCO2H0A1LIB81960.zkey"

Modified: gnunet/src/gns/test_gns_simple_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_simple_lookup.c     2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_simple_lookup.c     2012-09-14 11:24:58 UTC (rev 
23789)
@@ -41,7 +41,7 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.gnunet"
+#define TEST_DOMAIN "www.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 

Modified: gnunet/src/gns/test_gns_simple_mx_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_simple_mx_lookup.c  2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_simple_mx_lookup.c  2012-09-14 11:24:58 UTC (rev 
23789)
@@ -42,11 +42,11 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "bob.gnunet"
+#define TEST_DOMAIN "bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "mail"
 #define TEST_MX_NAME "mail.+"
-#define TEST_EXPECTED_MX "mail.bob.gnunet"
+#define TEST_EXPECTED_MX "mail.bob.gads"
 
 #define TEST_AUTHORITY_NAME "bob"
 

Modified: gnunet/src/gns/test_gns_simple_shorten.c
===================================================================
--- gnunet/src/gns/test_gns_simple_shorten.c    2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_simple_shorten.c    2012-09-14 11:24:58 UTC (rev 
23789)
@@ -42,14 +42,14 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.alice.bob.gnunet"
+#define TEST_DOMAIN "www.alice.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 
 #define TEST_AUTHORITY_BOB "bob"
 #define TEST_AUTHORITY_ALICE "alice"
 #define TEST_ALICE_PSEU "carol"
-#define TEST_EXPECTED_RESULT "www.carol.gnunet"
+#define TEST_EXPECTED_RESULT "www.carol.gads"
 
 #define KEYFILE_BOB 
"../namestore/zonefiles/HGU0A0VCU334DN7F2I9UIUMVQMM7JMSD142LIMNUGTTV9R0CF4EG.zkey"
 #define KEYFILE_ALICE 
"../namestore/zonefiles/N0UJMP015AFUNR2BTNM3FKPBLG38913BL8IDMCO2H0A1LIB81960.zkey"

Modified: gnunet/src/gns/test_gns_simple_srv_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_simple_srv_lookup.c 2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_simple_srv_lookup.c 2012-09-14 11:24:58 UTC (rev 
23789)
@@ -43,12 +43,12 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "_sip._tcp.bob.gnunet"
+#define TEST_DOMAIN "_sip._tcp.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "sipserver"
 #define TEST_RECORD_NAME_SRV "_sip._tcp"
 #define TEST_SRV_NAME "sipserver.+"
-#define TEST_EXPECTED_SRV "sipserver.bob.gnunet"
+#define TEST_EXPECTED_SRV "sipserver.bob.gads"
 
 #define TEST_AUTHORITY_NAME "bob"
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- gnunet/src/gns/gnunet-gns-proxy.c   2012-09-14 10:43:08 UTC (rev 23788)
+++ gnunet/src/gns/gnunet-gns-proxy.c   2012-09-14 11:24:58 UTC (rev 23789)
@@ -2610,7 +2610,7 @@
                                  0, "DE", 2);
 
   gnutls_x509_crt_set_dn_by_oid (request, GNUTLS_OID_X520_ORGANIZATION_NAME,
-                                 0, "GNUnet", 6);
+                                 0, "GNS", 6);
 
   gnutls_x509_crt_set_dn_by_oid (request, GNUTLS_OID_X520_COMMON_NAME,
                                  0, name, strlen (name));

Modified: gnunet/src/gns/gnunet-service-gns_interceptor.c
===================================================================
--- gnunet/src/gns/gnunet-service-gns_interceptor.c     2012-09-14 10:43:08 UTC 
(rev 23788)
+++ gnunet/src/gns/gnunet-service-gns_interceptor.c     2012-09-14 11:24:58 UTC 
(rev 23789)
@@ -313,14 +313,14 @@
 
   if (p->num_queries > 1)
   {
     /* Note: We could also look for .gnunet */
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 ">1 queriy in DNS packet... odd. We only process #1\n");
   }
 
   
   /**
-   * Check for .gnunet/.zkey
+   * Check for .gads/.zkey
    */
   
   if ((is_gnunet_tld(p->queries[0].name) == GNUNET_YES) ||

Modified: gnunet/src/gns/gnunet-service-gns_resolver.c
===================================================================
--- gnunet/src/gns/gnunet-service-gns_resolver.c        2012-09-14 10:43:08 UTC 
(rev 23788)
+++ gnunet/src/gns/gnunet-service-gns_resolver.c        2012-09-14 11:24:58 UTC 
(rev 23789)
@@ -178,7 +178,7 @@
 /**
  * Determine if this name is canonical.
  * i.e.
- * a.b.gnunet  = not canonical
+ * a.b.gads  = not canonical
  * a           = canonical
  *
  * @param name the name to test
@@ -2121,7 +2121,7 @@
     {
       GNUNET_log(GNUNET_ERROR_TYPE_DEBUG,
         "GNS_PHASE_DELEGATE_REV-%llu: Starting background lookup for %s type 
%d\n",
-        rh->id, "+.gnunet", GNUNET_GNS_RECORD_REV);
+        rh->id, "+.gads", GNUNET_GNS_RECORD_REV);
 
       gns_resolver_lookup_record(rh->authority,
                                  rh->private_local_zone,
@@ -3645,7 +3645,7 @@
                                         nsh->shorten_zone) == 0)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */
@@ -3752,7 +3752,7 @@
                                         nsh->private_zone) == 0)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */
@@ -3863,7 +3863,7 @@
                                         nsh->root_zone) == 0)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */
@@ -3964,7 +3964,7 @@
                                    nsh->root_zone) == 0)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */
@@ -3980,7 +3980,7 @@
   else if (NULL != nsh->private_zone)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */
@@ -4001,7 +4001,7 @@
   else if (NULL != nsh->shorten_zone)
   {
     /**
      * This is our zone append .gnunet unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
      */

Modified: gnunet/src/gns/test_gns_cname_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_cname_lookup.c      2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_cname_lookup.c      2012-09-14 11:24:58 UTC (rev 
23789)
@@ -41,13 +41,13 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN_PLUS "www.gnunet"
-#define TEST_DOMAIN_ZKEY "www2.gnunet"
-#define TEST_DOMAIN_DNS  "www3.gnunet"
+#define TEST_DOMAIN_PLUS "www.gads"
+#define TEST_DOMAIN_ZKEY "www2.gads"
+#define TEST_DOMAIN_DNS  "www3.gads"
 #define TEST_IP_PLUS "127.0.0.1"
 #define TEST_IP_ZKEY "127.0.0.2"
 #define TEST_IP_DNS  "131.159.74.67"
-#define TEST_RECORD_CNAME_SERVER "server.gnunet"
+#define TEST_RECORD_CNAME_SERVER "server.gads"
 #define TEST_RECORD_CNAME_PLUS "server.+"
 #define TEST_RECORD_CNAME_ZKEY 
"www.188JSUMKEF25GVU8TTV0PBNNN8JVCPUEDFV1UHJJU884JD25V0T0.zkey"
 #define TEST_RECORD_CNAME_DNS "gnunet.org"

Modified: gnunet/src/gns/test_gns_dht_delegated_lookup.c
===================================================================
--- gnunet/src/gns/test_gns_dht_delegated_lookup.c      2012-09-14 10:43:08 UTC 
(rev 23788)
+++ gnunet/src/gns/test_gns_dht_delegated_lookup.c      2012-09-14 11:24:58 UTC 
(rev 23789)
@@ -46,7 +46,7 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.bob.gnunet"
+#define TEST_DOMAIN "www.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 

Modified: gnunet/src/gns/test_gns_dht_three_peers.c
===================================================================
--- gnunet/src/gns/test_gns_dht_three_peers.c   2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_dht_three_peers.c   2012-09-14 11:24:58 UTC (rev 
23789)
@@ -24,7 +24,7 @@
  * topology:
  * alice <----> bob <-----> dave
  *
  * alice queries for www.buddy.bob.gnunet
  *
  */
 #include "platform.h"
@@ -45,7 +45,7 @@
 /* If number of peers not in config file, use this number */
 #define DEFAULT_NUM_PEERS 2
 
-#define TEST_DOMAIN "www.buddy.bob.gnunet"
+#define TEST_DOMAIN "www.buddy.bob.gads"
 #define TEST_IP "1.1.1.1"
 #define TEST_DAVE_PSEU "hagbard"
 #define TEST_NUM_PEERS 3

Modified: gnunet/src/gns/test_gns_max_queries.c
===================================================================
--- gnunet/src/gns/test_gns_max_queries.c       2012-09-14 10:43:08 UTC (rev 
23788)
+++ gnunet/src/gns/test_gns_max_queries.c       2012-09-14 11:24:58 UTC (rev 
23789)
@@ -42,8 +42,8 @@
 #define DEFAULT_NUM_PEERS 2
 
 /* test records to resolve */
-#define TEST_DOMAIN "www.gnunet"
-#define TEST_DOMAIN_NACK "doesnotexist.bob.gnunet"
+#define TEST_DOMAIN "www.gads"
+#define TEST_DOMAIN_NACK "doesnotexist.bob.gads"
 #define TEST_IP "127.0.0.1"
 #define TEST_RECORD_NAME "www"
 #define TEST_ADDITIONAL_LOOKUPS 5
@@ -201,7 +201,7 @@
   {
     GNUNET_snprintf(lookup_name,
                     MAX_DNS_NAME_LENGTH,
-                    "www.doesnotexist-%d.bob.gnunet", i);
+                    "www.doesnotexist-%d.bob.gads", i);
     GNUNET_GNS_lookup(gns_handle, lookup_name, GNUNET_GNS_RECORD_A,
                       GNUNET_NO,
                       NULL,
@@ -313,14 +313,14 @@
   if (p->num_queries > 1)
   {
-    /* Note: We could also look for .gnunet */
+    /* Note: We could also look for .gads */
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 ">1 queriy in DNS packet... odd. We only process #1\n");
@@ -3645,7 +3645,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -3752,7 +3752,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -3863,7 +3863,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -3964,7 +3964,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -3980,7 +3980,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -4001,7 +4001,7 @@
   {
     /**
-     * This is our zone append .gnunet unless name is empty
+     * This is our zone append .gads unless name is empty
      * (it shouldn't be, usually FIXME what happens if we
      * shorten to our zone to a "" record??)
@@ -24,7 +24,7 @@
  * alice <----> bob <-----> dave
  *
- * alice queries for www.buddy.bob.gnunet
+ * alice queries for www.buddy.bob.gads
  *
  */

Modified: gnunet/src/gns/test_gns_ns_lookup.c
===================================================================